From 716a5de8870d7c02bb4d0aed72f30291b17b763a Mon Sep 17 00:00:00 2001 From: Timothy Pearson Date: Mon, 19 Dec 2011 11:59:01 -0600 Subject: Remove additional unneeded tq method conversions --- kmobile/DESIGN | 36 +++--- kmobile/TODO | 8 +- kmobile/devices/digicam/libkmobile_digicam.desktop | 2 +- kmobile/devices/gammu/libkmobile_gammu.desktop | 2 +- kmobile/devices/gnokii/gnokii_mobile.cpp | 62 ++++----- kmobile/devices/gnokii/gnokii_mobile.h | 4 +- kmobile/devices/gnokii/gnokiiconfigui.ui | 2 +- kmobile/devices/gnokii/libkmobile_gnokii.desktop | 2 +- .../devices/skeleton/libkmobile_skeleton.desktop | 2 +- kmobile/devices/skeleton/skeleton.cpp | 28 ++--- kmobile/devices/skeleton/skeleton.h | 4 +- kmobile/kioslave/kio_mobile.cpp | 80 ++++++------ kmobile/kioslave/mimetypes/mobile_device.desktop | 2 +- kmobile/kmobile.cpp | 40 +++--- kmobile/kmobile_selectiondialog.ui | 2 +- kmobile/kmobileclient.cpp | 90 +++++++------- kmobile/kmobileclient.h | 40 +++--- kmobile/kmobiledevice.cpp | 64 +++++----- kmobile/kmobiledevice.h | 58 ++++----- kmobile/kmobileiface.h | 44 +++---- kmobile/kmobileitem.cpp | 36 +++--- kmobile/kmobileitem.h | 4 +- kmobile/kmobileui.rc | 16 +-- kmobile/kmobileview.cpp | 138 ++++++++++----------- kmobile/kmobileview.h | 46 +++---- kmobile/libkmobile.desktop | 2 +- kmobile/main.cpp | 2 +- kmobile/systemtray.cpp | 6 +- kmobile/testlibkmobile.cpp | 14 +-- 29 files changed, 418 insertions(+), 418 deletions(-) (limited to 'kmobile') diff --git a/kmobile/DESIGN b/kmobile/DESIGN index 96dea2b1..287a3d9a 100644 --- a/kmobile/DESIGN +++ b/kmobile/DESIGN @@ -7,10 +7,10 @@ "kmobile" is suite to easily access "Mobile Devices", which means, that you have one single interface to access -any type of mobile tqdevice (e.g. cellular phone, PDAs, +any type of mobile device (e.g. cellular phone, PDAs, MP3-Players, Digital Cameras and a lot more). -Each of this tqdevices have different types of information, +Each of this devices have different types of information, (capatibilities) which can be: - An addressbook - A collection of notes @@ -18,28 +18,28 @@ Each of this tqdevices have different types of information, - a file storage section (e.g. pictures in digital cameras) - and more -The whole interface is pretty extendable. Each tqdevice has -a tqdevice driver, which reports the capatibilities of the -connected tqdevice to the higher level. -So, if you once write a tqdevice driver, you can access it's +The whole interface is pretty extendable. Each device has +a device driver, which reports the capatibilities of the +connected device to the higher level. +So, if you once write a device driver, you can access it's contents from any KDE application later. Currently the whole interface is divided into 3 sections: -a) The low-level tqdevice driver +a) The low-level device driver b) A mid-layer, which is realized in the "kmobile" application c) A userland library, to which KDE applications should link. Here is some background info: -a) The low-level tqdevice driver (libkmobile_xxxx.so) +a) The low-level device driver (libkmobile_xxxx.so) The low-level driver has to be derived from the KMobileDevice class (#include ). The drivers should be located below the -directory /tqdevice, and you can find a sample implementation in -/tqdevice/skeleton-directory. See below for some hints on how to -write such a tqdevice driver. +directory /device, and you can find a sample implementation in +/device/skeleton-directory. See below for some hints on how to +write such a device driver. b) The mid-layer (kmobile) @@ -47,7 +47,7 @@ b) The mid-layer (kmobile) The mid-layer handles the main functionality, which is entirely implemented in the kmobile application. All low-level drivers are loaded by kmobile only, and then all low-level functions -to any tqdevice is made available to other applications +to any device is made available to other applications with a DCOP interface. Normal KDE applications should prefer the userland library (see below) instead of using direct DCOP calls. Nevertheless, the DCOP interface might be very interesting to write @@ -56,14 +56,14 @@ standalone command line tools. c) The userland library (libkmobileclient.so) -Any KDE application which wants to access mobile tqdevices +Any KDE application which wants to access mobile devices should #include and link to the libkmobileclient.la library. libkmobileclient translates all calls to DCOP calls and -makes accessing mobile tqdevices completely transparent to the +makes accessing mobile devices completely transparent to the application. One sample program which uses the client library is the kmobile -kioslave. In Konqueror you might access any mobile tqdevice directly +kioslave. In Konqueror you might access any mobile device directly by giving "mobile:/" as the URL. @@ -72,7 +72,7 @@ by giving "mobile:/" as the URL. HINTS FOR DRIVER DEVELOPERS: ---------------------------- -- KMobile tqdevice drivers are very similiar to kioslaves. Refer +- KMobile device drivers are very similiar to kioslaves. Refer at the kioslave documentation if needed. - derive your driver only from the KMobileDevice class (#include ) @@ -86,8 +86,8 @@ HINTS FOR DRIVER DEVELOPERS: all calls to your driver, so you always will have a clean state - use lockDevice("/dev/ttyS1") and unlockDevice("/dev/ttyS1") to - lock those tqdevices system-wide (creates /var/lock/LCK.. files), - and to prevent other applications to access the same physical ports/tqdevices + lock those devices system-wide (creates /var/lock/LCK.. files), + and to prevent other applications to access the same physical ports/devices - use the helper functions createDirEntry() and createFileEntry() to create the right UDSEntries for listEntries(), stat(), ... diff --git a/kmobile/TODO b/kmobile/TODO index 308ce674..457393bb 100644 --- a/kmobile/TODO +++ b/kmobile/TODO @@ -1,7 +1,7 @@ DONE: ----- -- tqdevices:/ kioslave integration -- show per-tqdevice icons in konqueror (same as in the kmobile view) +- devices:/ kioslave integration +- show per-device icons in konqueror (same as in the kmobile view) - fix mimetypes and their location under /share/mimelnk - kioslaves: cellphone:/, organizer:/, pda:/, (camera:/ not activated) - system tray plugin @@ -10,11 +10,11 @@ DONE: TODO: ----- - fix doubled loading of plugins -- where do I get the tqdevice name from the kmobile unique process? +- where do I get the device name from the kmobile unique process? - finish the functions which are available to client apps. - kitchensync driver/plugin (starting...) - a plugin for the left side of the "Open File Dialog". -> - makes direct access to mobile tqdevices really easy + makes direct access to mobile devices really easy - make the daemon a KDED (KDE Meta Daemon) module (tdelibs/kded/HOWTO, README.kded) - more drivers (always) diff --git a/kmobile/devices/digicam/libkmobile_digicam.desktop b/kmobile/devices/digicam/libkmobile_digicam.desktop index 6e39cce6..adb3c9ab 100644 --- a/kmobile/devices/digicam/libkmobile_digicam.desktop +++ b/kmobile/devices/digicam/libkmobile_digicam.desktop @@ -107,6 +107,6 @@ Comment[uk]=Цей драйвер підтримує багато цифрови Comment[zh_CN]=此驱动程序支持许多数码相机 Comment[zh_TW]=此驅動程式支援許多數位相機 Type=Service -ServiceTypes=kdetqdevice/mobiletqdevice +ServiceTypes=kdedevice/mobiledevice X-KDE-Library=libkmobile_digicam Icon=mobile_camera diff --git a/kmobile/devices/gammu/libkmobile_gammu.desktop b/kmobile/devices/gammu/libkmobile_gammu.desktop index daaa2372..f706b680 100644 --- a/kmobile/devices/gammu/libkmobile_gammu.desktop +++ b/kmobile/devices/gammu/libkmobile_gammu.desktop @@ -101,6 +101,6 @@ Comment[uk]=Цей драйвер підтримує багато мобільн Comment[zh_CN]=此驱动程序通过 gammu 库支持许多诺基亚和其它移动电话 Comment[zh_TW]=此驅動程式支援許多 NOKIA 及其他手機,使用 gammu 函式庫 Type=Service -ServiceTypes=kdetqdevice/mobiletqdevice +ServiceTypes=kdedevice/mobiledevice X-KDE-Library=libkmobile_gammu Icon=mobile_phone diff --git a/kmobile/devices/gnokii/gnokii_mobile.cpp b/kmobile/devices/gnokii/gnokii_mobile.cpp index c4f31579..48c3b8ae 100644 --- a/kmobile/devices/gnokii/gnokii_mobile.cpp +++ b/kmobile/devices/gnokii/gnokii_mobile.cpp @@ -48,7 +48,7 @@ #define GNOKII_CHECK_ERROR(error) \ do { \ if (error) \ - PRINT_DEBUG << TQString("ERROR %1: %2\n").tqarg(error).tqarg(gn_error_print(error));\ + PRINT_DEBUG << TQString("ERROR %1: %2\n").arg(error).arg(gn_error_print(error));\ } while (0) @@ -74,16 +74,16 @@ static gn_calnote_list calnote_list; /** - * The KDE gnokii mobile tqdevice driver. + * The KDE gnokii mobile device driver. */ KMobileGnokii::KMobileGnokii(TQObject *obj, const char *name, const TQStringList &args ) : KMobileDevice(obj, name, args) { - // set initial tqdevice info + // set initial device info setClassType( Phone ); - m_tqdeviceName = i18n("Mobile Phone accessed via GNOKII"); - m_tqdeviceRevision = ""; + m_deviceName = i18n("Mobile Phone accessed via GNOKII"); + m_deviceRevision = ""; m_connectionName = "/dev/ircomm0"; setCapabilities( hasAddressBook | hasNotes ); @@ -103,8 +103,8 @@ KMobileGnokii::KMobileGnokii(TQObject *obj, const char *name, const TQStringList m_baud = "9600"; } - PRINT_DEBUG << TQString("Using GNOKII configuration: %1 %2 %3 %4\n").tqarg(m_modelnr) - .tqarg(m_connection).tqarg(m_port).tqarg(m_baud); + PRINT_DEBUG << TQString("Using GNOKII configuration: %1 %2 %3 %4\n").arg(m_modelnr) + .arg(m_connection).arg(m_port).arg(m_baud); saveDeviceConfiguration(); saveGnokiiConfiguration(); @@ -148,7 +148,7 @@ bool KMobileGnokii::setGnokiiStateMachine() { // set the state machine to our configuration qstrncpy( state.config.model, m_modelnr.utf8(), sizeof(state.config.model)-1 ); - qstrncpy( state.config.port_tqdevice, m_port.utf8(), sizeof(state.config.port_tqdevice)-1 ); + qstrncpy( state.config.port_device, m_port.utf8(), sizeof(state.config.port_device)-1 ); state.config.connection_type = connectionToValue(m_connection); state.config.serial_baudrate = m_baud.toUInt(); return true; @@ -206,7 +206,7 @@ bool KMobileGnokii::loadDeviceConfiguration() static void busterminate(void) { gn_sm_functions(GN_OP_Terminate, NULL, &state); - if (lockfile) gn_tqdevice_unlock(lockfile); + if (lockfile) gn_device_unlock(lockfile); } static TQString businit(void) @@ -222,7 +222,7 @@ static TQString businit(void) aux = gn_cfg_get(gn_cfg_info, "global", "use_locking"); // Defaults to 'no' if (aux && !strcmp(aux, "yes")) { - lockfile = gn_tqdevice_lock(state.config.port_tqdevice); + lockfile = gn_device_lock(state.config.port_device); if (lockfile == NULL) { return i18n("Lock file error.\n " "Please exit all other running instances of gnokii and try again."); @@ -237,7 +237,7 @@ static TQString businit(void) state.config.require_dcd = old_dcd; if (error != GN_ERR_NONE) { busterminate(); - return i18n("Mobile phone interface initialization failed:\n%1").tqarg(gn_error_print(error)); + return i18n("Mobile phone interface initialization failed:\n%1").arg(gn_error_print(error)); } // model @@ -265,9 +265,9 @@ static TQString businit(void) data.imei = NULL; GNOKII_DEBUG( TQString("Found mobile phone: Model: %1, Revision: %2, IMEI: %3\n") - .tqarg(model).tqarg(revision).tqarg(imei) ); + .arg(model).arg(revision).arg(imei) ); - PhoneProductId = TQString("%1-%2-%3-%4").tqarg(APP).tqarg(model).tqarg(revision).tqarg(imei); + PhoneProductId = TQString("%1-%2-%3-%4").arg(APP).arg(model).arg(revision).arg(imei); return TQString(); } @@ -299,7 +299,7 @@ static gn_error read_phone_memstat( gn_memory_type memtype, gn_memory_status *me } } GNOKII_DEBUG( TQString("\n\nMobile phone memory status: Type: %1, used=%2, free=%3, total=%4\n\n") - .tqarg(memtype).tqarg(memstat->used).tqarg(memstat->free).tqarg(memstat->used+memstat->free) ); + .arg(memtype).arg(memstat->used).arg(memstat->free).arg(memstat->used+memstat->free) ); return error; } @@ -372,8 +372,8 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt if (error != GN_ERR_NONE) return error; - GNOKII_DEBUG(TQString("%1: %2, num=%3, location=%4, group=%5, count=%6\n").tqarg(index).tqarg(entry.name) - .tqarg(entry.number).tqarg(entry.location).tqarg(entry.caller_group).tqarg(entry.subentries_count)); + GNOKII_DEBUG(TQString("%1: %2, num=%3, location=%4, group=%5, count=%6\n").arg(index).arg(entry.name) + .arg(entry.number).arg(entry.location).arg(entry.caller_group).arg(entry.subentries_count)); // try to split Name into FamilyName and GivenName s = TQString(entry.name).simplifyWhiteSpace(); @@ -395,7 +395,7 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt } a->insertCustom(APP, "X_GSM_CALLERGROUP", s.setNum(entry.caller_group)); - a->insertCustom(APP, "X_GSM_STORE_AT", TQString("%1_%2").tqarg(GN_MT_ME).tqarg(entry.location)); + a->insertCustom(APP, "X_GSM_STORE_AT", TQString("%1_%2").arg(GN_MT_ME).arg(entry.location)); // set ProductId a->setProductId(PhoneProductId); @@ -407,7 +407,7 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt else datetime = TQDateTime( TQDate(entry.date.year, entry.date.month, entry.date.day), TQTime(entry.date.hour, entry.date.minute, entry.date.second) ); - GNOKII_DEBUG(TQString(" date=%1\n").tqarg(datetime.toString())); + GNOKII_DEBUG(TQString(" date=%1\n").arg(datetime.toString())); a->setRevision(datetime); if (!entry.subentries_count) @@ -418,8 +418,8 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt for (int n=0; n=numAddresses()) return KIO::ERR_DOES_NOT_EXIST; @@ -609,7 +609,7 @@ int KMobileGnokii::readAddress( int index, KABC::Addressee &addr ) int KMobileGnokii::storeAddress( int, const KABC::Addressee &, bool ) { - /* XXX: this is a read-only tqdevice */ + /* XXX: this is a read-only device */ return KIO::ERR_WRITE_ACCESS_DENIED; } @@ -870,8 +870,8 @@ int KMobileGnokii::readNote( int index, TQString ¬e ) "DeviceClassName: %3\n" "Device Driver : %4\n" "Device Revision: %5\n") - .tqarg(index).tqarg(index) - .tqarg(tqdeviceClassName()).tqarg(tqdeviceName()).tqarg(revision()); + .arg(index).arg(index) + .arg(deviceClassName()).arg(deviceName()).arg(revision()); return 0; } diff --git a/kmobile/devices/gnokii/gnokii_mobile.h b/kmobile/devices/gnokii/gnokii_mobile.h index 96f32a5c..e3fe7bde 100644 --- a/kmobile/devices/gnokii/gnokii_mobile.h +++ b/kmobile/devices/gnokii/gnokii_mobile.h @@ -43,13 +43,13 @@ public: bool connectDevice(TQWidget *parent); bool disconnectDevice(TQWidget *parent); - // provide a tqdevice-specific configure dialog + // provide a device-specific configure dialog bool configDialog(TQWidget *parent); // filename and path to gnokii-icon TQString iconFileName() const; - TQString tqdeviceUniqueID(); + TQString deviceUniqueID(); /* * Addressbook / Phonebook support diff --git a/kmobile/devices/gnokii/gnokiiconfigui.ui b/kmobile/devices/gnokii/gnokiiconfigui.ui index 255b6fb6..e7f6bb31 100644 --- a/kmobile/devices/gnokii/gnokiiconfigui.ui +++ b/kmobile/devices/gnokii/gnokiiconfigui.ui @@ -127,7 +127,7 @@ textLabel2 - Please configure your Gnokii mobile tqdevice + Please configure your Gnokii mobile device diff --git a/kmobile/devices/gnokii/libkmobile_gnokii.desktop b/kmobile/devices/gnokii/libkmobile_gnokii.desktop index 986eded0..7e732ecd 100644 --- a/kmobile/devices/gnokii/libkmobile_gnokii.desktop +++ b/kmobile/devices/gnokii/libkmobile_gnokii.desktop @@ -101,6 +101,6 @@ Comment[uk]=Цей драйвер підтримує багато мобільн Comment[zh_CN]=此驱动程序通过 gnokii 库支持许多诺基亚和其它移动电话 Comment[zh_TW]=此驅動程式支援許多 NOKIA 及其他手機,使用 gnokii 函式庫 Type=Service -ServiceTypes=kdetqdevice/mobiletqdevice +ServiceTypes=kdedevice/mobiledevice X-KDE-Library=libkmobile_gnokii Icon=mobile_phone diff --git a/kmobile/devices/skeleton/libkmobile_skeleton.desktop b/kmobile/devices/skeleton/libkmobile_skeleton.desktop index 2b22ca6e..72943d15 100644 --- a/kmobile/devices/skeleton/libkmobile_skeleton.desktop +++ b/kmobile/devices/skeleton/libkmobile_skeleton.desktop @@ -102,6 +102,6 @@ Comment[uk]=Прототип мобільного пристрою Comment[zh_CN]=移动万能设备 Comment[zh_TW]=行動通訊空殼裝置 Type=Service -ServiceTypes=kdetqdevice/mobiletqdevice +ServiceTypes=kdedevice/mobiledevice X-KDE-Library=libkmobile_skeleton Icon=mobile_unknown diff --git a/kmobile/devices/skeleton/skeleton.cpp b/kmobile/devices/skeleton/skeleton.cpp index b5073de8..e6b1d9c5 100644 --- a/kmobile/devices/skeleton/skeleton.cpp +++ b/kmobile/devices/skeleton/skeleton.cpp @@ -43,16 +43,16 @@ TQObject *KMobileSkeleton::createObject( TQObject *parent, const char *name, /** - * The KDE skeleton mobile tqdevice driver. + * The KDE skeleton mobile device driver. */ KMobileSkeleton::KMobileSkeleton(TQObject *obj, const char *name, const TQStringList &args ) : KMobileDevice(obj, name, args) { - // set initial tqdevice info + // set initial device info setClassType( Phone ); - m_tqdeviceName = i18n("LX-50-Moohoo Addressbook (Skeleton)"); - m_tqdeviceRevision = "0.1"; + m_deviceName = i18n("LX-50-Moohoo Addressbook (Skeleton)"); + m_deviceRevision = "0.1"; setCapabilities( hasAddressBook | hasNotes ); } @@ -60,26 +60,26 @@ KMobileSkeleton::~KMobileSkeleton() { } -// connect the tqdevice and ask user to turn tqdevice on (if necessary) +// connect the device and ask user to turn device on (if necessary) bool KMobileSkeleton::connectDevice(TQWidget *parent) { if (KMessageBox::Continue != KMessageBox::warningContinueCancel(parent, - i18n("Please turn on your %1 on now and press continue to proceed.").tqarg(m_tqdeviceName), - m_tqdeviceClassName ) ) + i18n("Please turn on your %1 on now and press continue to proceed.").arg(m_deviceName), + m_deviceClassName ) ) return false; // connect it now... m_connected = true; return m_connected; } -// disconnect the tqdevice and return true, if sucessful +// disconnect the device and return true, if sucessful bool KMobileSkeleton::disconnectDevice(TQWidget *) { m_connected = true; return true; } -// returns true, if this tqdevice is read-only (default: false) +// returns true, if this device is read-only (default: false) bool KMobileSkeleton::isReadOnly() const { return true; @@ -87,7 +87,7 @@ bool KMobileSkeleton::isReadOnly() const // return a unique ID, e.g. the IMEI number of phones, or a serial number // this String is used to have a unique identification for syncronisation. -TQString KMobileSkeleton::tqdeviceUniqueID() +TQString KMobileSkeleton::deviceUniqueID() { return TQString::fromLocal8Bit("SkElEtOn-123456789"); } @@ -112,7 +112,7 @@ int KMobileSkeleton::readAddress( int index, KABC::Addressee &addr ) return KIO::ERR_DOES_NOT_EXIST; // now build our own sample name - addr.setFamilyName(TQString("Meyer_%1").tqarg(index+1)); + addr.setFamilyName(TQString("Meyer_%1").arg(index+1)); addr.setGivenName("Peter"); addr.setFormattedName("Peter "+addr.familyName()); addr.setNickName("PeterM"); @@ -132,7 +132,7 @@ int KMobileSkeleton::readAddress( int index, KABC::Addressee &addr ) int KMobileSkeleton::storeAddress( int, const KABC::Addressee &, bool ) { - /* this is a read-only tqdevice */ + /* this is a read-only device */ return KIO::ERR_WRITE_ACCESS_DENIED; } @@ -156,8 +156,8 @@ int KMobileSkeleton::readNote( int index, TQString ¬e ) "DeviceClassName: %3\n" "Device Driver : %4\n" "Device Revision: %5\n") - .tqarg(index).tqarg(index) - .tqarg(tqdeviceClassName()).tqarg(tqdeviceName()).tqarg(revision()); + .arg(index).arg(index) + .arg(deviceClassName()).arg(deviceName()).arg(revision()); return 0; } diff --git a/kmobile/devices/skeleton/skeleton.h b/kmobile/devices/skeleton/skeleton.h index 6ae0287b..ab3ce770 100644 --- a/kmobile/devices/skeleton/skeleton.h +++ b/kmobile/devices/skeleton/skeleton.h @@ -42,14 +42,14 @@ public: bool connectDevice(TQWidget *parent); bool disconnectDevice(TQWidget *parent); - // returns true, if this tqdevice is read-only (default: false) + // returns true, if this device is read-only (default: false) bool isReadOnly() const; // you may provide your own icon() implementation to display // an appropriate Pixmap (e.g. a Palm Pilot or a Zaurus image). TQString iconFileName() const; - TQString tqdeviceUniqueID(); + TQString deviceUniqueID(); /* * Addressbook / Phonebook support diff --git a/kmobile/kioslave/kio_mobile.cpp b/kmobile/kioslave/kio_mobile.cpp index ed570196..d8216bcd 100644 --- a/kmobile/kioslave/kio_mobile.cpp +++ b/kmobile/kioslave/kio_mobile.cpp @@ -78,13 +78,13 @@ KMobileProtocol::~KMobileProtocol() } /* - * getDeviceAndRessource("mobile:///...") - split + * getDeviceAndRessource("mobile:///...") - split */ int KMobileProtocol::getDeviceAndRessource(const TQString &_path, TQString &devName, TQString &resource, TQString &devPath, KMobileDevice::Capabilities &devCaps) { -// PRINT_DEBUG << TQString("###getDeviceAndRessource### %1\n").tqarg(_path); +// PRINT_DEBUG << TQString("###getDeviceAndRessource### %1\n").arg(_path); TQStringList path = TQStringList::split('/', _path, false); devName = resource = devPath = TQString(); @@ -140,7 +140,7 @@ void createDirEntry(KIO::UDSEntry& entry, const TQString& name, const TQString& addAtom(entry, KIO::UDS_URL, 0, url); addAtom(entry, KIO::UDS_USER, 0, getenv("USER")); addAtom(entry, KIO::UDS_GROUP, 0, getenv("USER")); - PRINT_DEBUG << TQString("createDirEntry: File: %1 MIME: %2 URL: %3\n").tqarg(name).tqarg(mime).tqarg(url); + PRINT_DEBUG << TQString("createDirEntry: File: %1 MIME: %2 URL: %3\n").arg(name).arg(mime).arg(url); // addAtom(entry, KIO::UDS_SIZE, 0); addAtom(entry, KIO::UDS_GUESSED_MIME_TYPE, 0, mime); } @@ -159,7 +159,7 @@ void createFileEntry(KIO::UDSEntry& entry, const TQString& name, const TQString& addAtom(entry, KIO::UDS_MIME_TYPE, 0, mime); if (size) addAtom(entry, KIO::UDS_SIZE, size); addAtom(entry, KIO::UDS_GUESSED_MIME_TYPE, 0, mime); - PRINT_DEBUG << TQString("createFileEntry: File: %1, Size: %2, MIME: %3\n").tqarg(name).tqarg(size).tqarg(mime); + PRINT_DEBUG << TQString("createFileEntry: File: %1, Size: %2, MIME: %3\n").arg(name).arg(size).arg(mime); } @@ -169,7 +169,7 @@ void createFileEntry(KIO::UDSEntry& entry, const TQString& name, const TQString& void KMobileProtocol::get(const KURL &url) { PRINT_DEBUG << "###############################\n"; - PRINT_DEBUG << TQString("get(%1)\n").tqarg(url.path()); + PRINT_DEBUG << TQString("get(%1)\n").arg(url.path()); KMobileDevice::Capabilities devCaps; TQString devName, resource, devPath; @@ -227,16 +227,16 @@ void KMobileProtocol::get(const KURL &url) /* - * listRoot() - gives listing of all tqdevices + * listRoot() - gives listing of all devices */ void KMobileProtocol::listRoot(const KURL& url) { - PRINT_DEBUG << TQString("########## listRoot(%1) for %2:/\n").tqarg(url.path()).tqarg(url.protocol()); + PRINT_DEBUG << TQString("########## listRoot(%1) for %2:/\n").arg(url.path()).arg(url.protocol()); KIO::UDSEntry entry; - TQStringList tqdeviceNames = m_dev.tqdeviceNames(); - unsigned int dirs = tqdeviceNames.count(); + TQStringList deviceNames = m_dev.deviceNames(); + unsigned int dirs = deviceNames.count(); totalSize(dirs); int classMask = KMobileDevice::Unclassified; @@ -251,7 +251,7 @@ void KMobileProtocol::listRoot(const KURL& url) for (unsigned int i=0; i") - sub-directory of a tqdevices + * listTopDeviceDir("mobile:/") - sub-directory of a devices */ void KMobileProtocol::listTopDeviceDir(const TQString &devName) { - PRINT_DEBUG << TQString("listTopDeviceDir(%1)\n").tqarg(devName); + PRINT_DEBUG << TQString("listTopDeviceDir(%1)\n").arg(devName); KIO::UDSEntry entry; unsigned int caps = m_dev.capabilities(devName); @@ -325,7 +325,7 @@ void KMobileProtocol::listTopDeviceDir(const TQString &devName) TQString filename = m_dev.nameForCap(devName, cap); TQString mimetype = folderMimeType(cap); - createDirEntry(entry, filename, TQString("mobile:/%1/%2/").tqarg(devName).tqarg(filename), mimetype); + createDirEntry(entry, filename, TQString("mobile:/%1/%2/").arg(devName).arg(filename), mimetype); listEntry(entry, false); } listEntry(entry, true); @@ -334,13 +334,13 @@ void KMobileProtocol::listTopDeviceDir(const TQString &devName) /* - * listEntries("mobile://") - resources of a tqdevice + * listEntries("mobile://") - resources of a device */ void KMobileProtocol::listEntries(const TQString &devName, const TQString &resource, const TQString &devPath, const KMobileDevice::Capabilities devCaps) { - PRINT_DEBUG << TQString("listEntries(%1,%2,%3)\n").tqarg(devName).tqarg(resource).tqarg(devPath); + PRINT_DEBUG << TQString("listEntries(%1,%2,%3)\n").arg(devName).arg(resource).arg(devPath); switch (devCaps) { case KMobileDevice::hasAddressBook: listAddressBook(devName, resource); break; @@ -351,16 +351,16 @@ void KMobileProtocol::listEntries(const TQString &devName, case KMobileDevice::hasFileStorage: listFileStorage(devName, resource, devPath); break; default: error( ERR_CANNOT_ENTER_DIRECTORY, - TQString("/%1/%2").tqarg(devName).tqarg(resource) ); + TQString("/%1/%2").arg(devName).arg(resource) ); } } /* - * listAddressBook("mobile://Addressbook) - list the addressbook + * listAddressBook("mobile://Addressbook) - list the addressbook */ void KMobileProtocol::listAddressBook(const TQString &devName, const TQString &resource) { - PRINT_DEBUG << TQString("listAddressBook(%1)\n").tqarg(devName); + PRINT_DEBUG << TQString("listAddressBook(%1)\n").arg(devName); KIO::UDSEntry entry; @@ -382,11 +382,11 @@ void KMobileProtocol::listAddressBook(const TQString &devName, const TQString &r name = "_" + rx.cap(1); #endif - TQString filename = TQString("%1%2.vcf").tqarg(i,fieldwidth).tqarg(name); + TQString filename = TQString("%1%2.vcf").arg(i,fieldwidth).arg(name); for (int p=0; p0) @@ -421,11 +421,11 @@ int KMobileProtocol::getVCard( const TQString &devName, TQCString &result, TQStr } /* - * listCalendar("mobile://Calendar) - list the calendar entries + * listCalendar("mobile://Calendar) - list the calendar entries */ void KMobileProtocol::listCalendar( const TQString &devName, const TQString &resource) { - PRINT_DEBUG << TQString("listCalendar(%1)\n").tqarg(devName); + PRINT_DEBUG << TQString("listCalendar(%1)\n").arg(devName); KIO::UDSEntry entry; @@ -433,8 +433,8 @@ void KMobileProtocol::listCalendar( const TQString &devName, const TQString &res totalSize(entries); for (int i=0; i/Notes) - list the notes + * listNotes("mobile://Notes) - list the notes */ void KMobileProtocol::listNotes( const TQString &devName, const TQString &resource) { - PRINT_DEBUG << TQString("listNotes(%1)\n").tqarg(devName); + PRINT_DEBUG << TQString("listNotes(%1)\n").arg(devName); KIO::UDSEntry entry; @@ -474,8 +474,8 @@ void KMobileProtocol::listNotes( const TQString &devName, const TQString &resour TQString note /*= m_dev.readNote(devName, i)*/; - TQString filename = TQString("%1_%2.txt").tqarg(i).tqarg(i18n("note")); - TQString url = TQString("mobile:/%1/%2/%3").tqarg(devName).tqarg(resource).tqarg(filename); + TQString filename = TQString("%1_%2.txt").arg(i).arg(i18n("note")); + TQString url = TQString("mobile:/%1/%2/%3").arg(devName).arg(resource).arg(filename); createFileEntry(entry, filename, url, entryMimeType(KMobileDevice::hasNotes), 0 /*note.utf8().length()*/); @@ -492,7 +492,7 @@ void KMobileProtocol::listNotes( const TQString &devName, const TQString &resour */ int KMobileProtocol::getNote( const TQString &devName, TQCString &result, TQString &mime, const TQString &path ) { - PRINT_DEBUG << TQString("getNote(%1)\n").tqarg(path); + PRINT_DEBUG << TQString("getNote(%1)\n").arg(path); int index = path.find('_'); if (index>0) @@ -510,14 +510,14 @@ int KMobileProtocol::getNote( const TQString &devName, TQCString &result, TQStri } /* - * listFileStorage("mobile://Files) - list the files on the tqdevice + * listFileStorage("mobile://Files) - list the files on the device */ void KMobileProtocol::listFileStorage(const TQString &devName, const TQString &resource, const TQString &devPath) { - PRINT_DEBUG << TQString("listFileStorage(%1,%2)\n").tqarg(devName).tqarg(devPath); + PRINT_DEBUG << TQString("listFileStorage(%1,%2)\n").arg(devName).arg(devPath); /* TODO */ - error( KIO::ERR_DOES_NOT_EXIST, TQString("/%1/%2/%3").tqarg(devName).tqarg(resource).tqarg(devPath) ); + error( KIO::ERR_DOES_NOT_EXIST, TQString("/%1/%2/%3").arg(devName).arg(resource).arg(devPath) ); } /* @@ -525,7 +525,7 @@ void KMobileProtocol::listFileStorage(const TQString &devName, const TQString &r */ int KMobileProtocol::getFileStorage(const TQString &devName, TQCString &result, TQString &mime, const TQString &path) { - PRINT_DEBUG << TQString("getFileStorage(%1)\n").tqarg(path); + PRINT_DEBUG << TQString("getFileStorage(%1)\n").arg(path); /* TODO */ Q_UNUSED(devName); @@ -541,7 +541,7 @@ int KMobileProtocol::getFileStorage(const TQString &devName, TQCString &result, void KMobileProtocol::stat( const KURL &url ) { PRINT_DEBUG << "###############################\n"; - PRINT_DEBUG << TQString("stat(%1)\n").tqarg(url.path()); + PRINT_DEBUG << TQString("stat(%1)\n").arg(url.path()); KMobileDevice::Capabilities devCaps; TQString devName, resource, devPath; @@ -555,7 +555,7 @@ void KMobileProtocol::stat( const KURL &url ) TQStringList path = TQStringList::split('/', url.path(), false); TQString filename = (path.count()>0) ? path[path.count()-1] : "/"; TQString fullPath = path.join("/"); - TQString fullUrl = TQString("mobile:/%1").tqarg(fullPath); + TQString fullUrl = TQString("mobile:/%1").arg(fullPath); UDSEntry entry; @@ -577,7 +577,7 @@ void KMobileProtocol::stat( const KURL &url ) void KMobileProtocol::mimetype(const KURL &url) { PRINT_DEBUG << "###############################\n"; - PRINT_DEBUG << TQString("mimetype(%1)\n").tqarg(url.path()); + PRINT_DEBUG << TQString("mimetype(%1)\n").arg(url.path()); KMobileDevice::Capabilities devCaps; TQString devName, resource, devPath; @@ -599,7 +599,7 @@ void KMobileProtocol::mimetype(const KURL &url) void KMobileProtocol::listDir(const KURL &url) { PRINT_DEBUG << "###############################\n"; - PRINT_DEBUG << TQString("listDir(%1)\n").tqarg(url.path()); + PRINT_DEBUG << TQString("listDir(%1)\n").arg(url.path()); if (!m_dev.isKMobileAvailable()) { error( KIO::ERR_CONNECTION_BROKEN, i18n("KDE Mobile Device Manager") ); @@ -622,7 +622,7 @@ void KMobileProtocol::listDir(const KURL &url) #if 0 if (!dev) { - error( KIO::ERR_DOES_NOT_EXIST, TQString("/%1").tqarg(devName) ); + error( KIO::ERR_DOES_NOT_EXIST, TQString("/%1").arg(devName) ); return; } #endif diff --git a/kmobile/kioslave/mimetypes/mobile_device.desktop b/kmobile/kioslave/mimetypes/mobile_device.desktop index a04b0b8f..4462b124 100644 --- a/kmobile/kioslave/mimetypes/mobile_device.desktop +++ b/kmobile/kioslave/mimetypes/mobile_device.desktop @@ -58,7 +58,7 @@ Comment[zh_CN]=移动设备 Comment[zh_TW]=行動裝置 Icon=kmobile Type=MimeType -MimeType=kdetqdevice/mobiletqdevice +MimeType=kdedevice/mobiledevice Patterns= X-KDE-AutoEmbed=true diff --git a/kmobile/kmobile.cpp b/kmobile/kmobile.cpp index 8bd1da8a..d7628254 100644 --- a/kmobile/kmobile.cpp +++ b/kmobile/kmobile.cpp @@ -77,7 +77,7 @@ KMobile::KMobile() connect(m_view, TQT_SIGNAL(signalChangeStatusbar(const TQString&)), this, TQT_SLOT(changeStatusbar(const TQString&))); - // restore all configured tqdevices + // restore all configured devices restoreAll(); // setup the system tray @@ -105,13 +105,13 @@ void KMobile::setupActions() KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(optionsPreferences()), actionCollection()); new KAction(i18n("&Add Device..."), "folder_new", 0, - TQT_TQOBJECT(this), TQT_SLOT(addDevice()), actionCollection(), "tqdevice_add"); - new KAction( KGuiItem( i18n("&Remove Device"), "edittrash", i18n("Remove this tqdevice") ), - "Delete", TQT_TQOBJECT(this), TQT_SLOT(removeDevice()), actionCollection(), "tqdevice_remove"); + TQT_TQOBJECT(this), TQT_SLOT(addDevice()), actionCollection(), "device_add"); + new KAction( KGuiItem( i18n("&Remove Device"), "edittrash", i18n("Remove this device") ), + "Delete", TQT_TQOBJECT(this), TQT_SLOT(removeDevice()), actionCollection(), "device_remove"); new KAction(i18n("Re&name Device..."), 0, Key_F2, - TQT_TQOBJECT(this), TQT_SLOT(renameDevice()), actionCollection(), "tqdevice_rename"); + TQT_TQOBJECT(this), TQT_SLOT(renameDevice()), actionCollection(), "device_rename"); new KAction(i18n("&Configure Device..."), "configure", 0, - TQT_TQOBJECT(this), TQT_SLOT(configDevice()), actionCollection(), "tqdevice_configure"); + TQT_TQOBJECT(this), TQT_SLOT(configDevice()), actionCollection(), "device_configure"); createGUI(); @@ -240,7 +240,7 @@ void KMobile::optionsPreferences() void KMobile::renameDevice() { - // rename the current selected tqdevice + // rename the current selected device TQIconViewItem *item = m_view->currentItem(); if (item) item->rename(); @@ -258,7 +258,7 @@ void KMobile::addDevice() dialog->setCaption( i18n("Add New Mobile or Portable Device") ); - dialog->helpText->setText( i18n("Please select the category to which your new tqdevice belongs:") ); + dialog->helpText->setText( i18n("Please select the category to which your new device belongs:") ); dialog->addButton->setText( i18n("&Scan for New Devices...") ); dialog->addButton->setDisabled(true); dialog->iconView->connect( dialog->iconView, TQT_SIGNAL(doubleClicked(TQIconViewItem*)), @@ -273,7 +273,7 @@ void KMobile::addDevice() for ( it = list.begin(); it != list.end(); ++it ) { ptr = *it; kdDebug() << TQString("LIBRARY: '%1', NAME: '%2', ICON: '%3', COMMENT: '%4'\n") - .tqarg(ptr->library()).tqarg(ptr->name()).tqarg(ptr->icon()).tqarg(ptr->comment()); + .arg(ptr->library()).arg(ptr->name()).arg(ptr->icon()).arg(ptr->comment()); TQString iconName = ptr->icon(); if (iconName.isEmpty()) @@ -297,13 +297,13 @@ void KMobile::addDevice() ptr = list[index]; - // add the new tqdevice to the list + // add the new device to the list if (!m_view->addNewDevice(m_config, ptr)) { KMessageBox::error(this, TQString("KMobile could not load the %1 Device Driver.

" "Please use the Skeleton- or Gnokii Device Driver during development.

" "This driver will still be visible, but you won't be able to access it " - "from Konqueror or any other application.").tqarg(ptr->name()), + "from Konqueror or any other application.").arg(ptr->name()), kapp->name()); } @@ -313,7 +313,7 @@ void KMobile::addDevice() #if 0 /* * show dialog to user, in which he may choose and select one of the already - * configured mobile tqdevices. + * configured mobile devices. */ KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent, enum KMobileDevice::ClassType /*type*/, enum KMobileDevice::Capabilities /*caps*/ ) @@ -322,24 +322,24 @@ KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent, m_parent = parent; - // do we already have some tqdevices configured ? + // do we already have some devices configured ? num = readDevicesList(); if (!num) { int answ; answ = KMessageBox::questionYesNo(parent, - i18n( "You have no mobile tqdevices configured yet.

" - "Do you want to add a tqdevice now ?" ), + i18n( "You have no mobile devices configured yet.

" + "Do you want to add a device now ?" ), i18n( "KDE Mobile Device Access" ), KStdGuiItem::add(), i18n("Do Not Add") ); if (answ != KMessageBox::Yes) return 0L; - // add a new tqdevice + // add a new device addDeviceDialog(parent); } num = readDevicesList(); if (!num) return 0L; - // let the user select one of the configured tqdevices + // let the user select one of the configured devices KMobile_selectiondialog *dialog = new KMobile_selectiondialog(parent); if (!dialog) return 0L; @@ -357,7 +357,7 @@ KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent, continue; // kdDebug() << TQString("LIBRARY: '%1', NAME: '%2', ICON: '%3', COMMENT: '%4' #%5\n") - // .tqarg(ptr->library()).tqarg(ptr->name()).tqarg(ptr->icon()).tqarg(ptr->comment()).tqarg(i); + // .arg(ptr->library()).arg(ptr->name()).arg(ptr->icon()).arg(ptr->comment()).arg(i); TQString iconName = ptr->icon(); if (iconName.isEmpty()) @@ -384,7 +384,7 @@ KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent, void KMobile::removeDevice() { - // remove the current selected tqdevice + // remove the current selected device TQIconViewItem *item = m_view->currentItem(); if (item) m_view->removeDevice( item->text() ); @@ -392,7 +392,7 @@ void KMobile::removeDevice() void KMobile::configDevice() { - // configure the current selected tqdevice + // configure the current selected device TQIconViewItem *item = m_view->currentItem(); if (item) m_view->configDevice( item->text() ); diff --git a/kmobile/kmobile_selectiondialog.ui b/kmobile/kmobile_selectiondialog.ui index 621ec83d..2ad24ec4 100644 --- a/kmobile/kmobile_selectiondialog.ui +++ b/kmobile/kmobile_selectiondialog.ui @@ -32,7 +32,7 @@ helpText - <b>Select mobile tqdevice:</b> + <b>Select mobile device:</b> diff --git a/kmobile/kmobileclient.cpp b/kmobile/kmobileclient.cpp index 901aaf09..9c95efe8 100644 --- a/kmobile/kmobileclient.cpp +++ b/kmobile/kmobileclient.cpp @@ -36,10 +36,10 @@ KMobileClient::KMobileClient() m_kmobileObj = "kmobileIface"; bool ok = attach(); - PRINT_DEBUG << TQString("attached to DCOP server %1\n").tqarg(ok?"sucessful.":"failed."); + PRINT_DEBUG << TQString("attached to DCOP server %1\n").arg(ok?"sucessful.":"failed."); // m_clientAppId = registerAs("kmobileclient"); -// PRINT_DEBUG << TQString("registered as DCOP client %1\n").tqarg(m_clientAppId); +// PRINT_DEBUG << TQString("registered as DCOP client %1\n").arg(m_clientAppId); isKMobileAvailable(); } @@ -54,7 +54,7 @@ KMobileClient::~KMobileClient() bool KMobileClient::isKMobileAvailable() { bool available = isApplicationRegistered(m_kmobileApp); - PRINT_DEBUG << TQString("KMobile DCOP server: %1\n").tqarg(available?"available.":"not available"); + PRINT_DEBUG << TQString("KMobile DCOP server: %1\n").arg(available?"available.":"not available"); if (!available) { startKMobileApplication(); // check again... @@ -73,7 +73,7 @@ bool KMobileClient::startKMobileApplication() TQCString replyType; TQByteArray replyData; bool ok = call("klauncher", "klauncher", "tdeinit_exec_wait(TQString,TQStringList)", data, replyType, replyData); - PRINT_DEBUG << TQString("DCOP-CALL to klauncher: %1\n").tqarg(ok?"ok.":"failed."); + PRINT_DEBUG << TQString("DCOP-CALL to klauncher: %1\n").arg(ok?"ok.":"failed."); return ok; } @@ -93,7 +93,7 @@ bool KMobileClient::startKMobileApplication() TQCString replyType; \ TQByteArray replyData; \ bool ok = call(m_kmobileApp, m_kmobileObj, FUNC, data, replyType, replyData, KMOBILECLIENT_USE_EVENTLOOP, KMOBILECLIENT_TIMEOUT); \ - PRINT_DEBUG << TQString("DCOP-CALL to %1: %2\n").tqarg(FUNC).tqarg(ok?"ok.":"FAILED.") + PRINT_DEBUG << TQString("DCOP-CALL to %1: %2\n").arg(FUNC).arg(ok?"ok.":"FAILED.") #define RETURN_TYPE( FUNC, PARAMS, RETURN_TYPE ) \ PREPARE( FUNC, PARAMS ); \ @@ -122,110 +122,110 @@ bool KMobileClient::startKMobileApplication() -TQStringList KMobileClient::tqdeviceNames() +TQStringList KMobileClient::deviceNames() { if (!isKMobileAvailable()) return TQStringList(); - RETURN_TYPE( "tqdeviceNames()", TQString::fromLatin1(""), TQStringList ); + RETURN_TYPE( "deviceNames()", TQString::fromLatin1(""), TQStringList ); } -void KMobileClient::removeDevice( TQString tqdeviceName ) +void KMobileClient::removeDevice( TQString deviceName ) { - PREPARE( "removeDevice(TQString)", tqdeviceName ); + PREPARE( "removeDevice(TQString)", deviceName ); Q_UNUSED(ok); } -void KMobileClient::configDevice( TQString tqdeviceName ) +void KMobileClient::configDevice( TQString deviceName ) { - PREPARE( "configDevice(TQString)", tqdeviceName ); + PREPARE( "configDevice(TQString)", deviceName ); Q_UNUSED(ok); } -bool KMobileClient::connectDevice( TQString tqdeviceName ) +bool KMobileClient::connectDevice( TQString deviceName ) { - RETURN_BOOL( "connectDevice(TQString)", tqdeviceName ); + RETURN_BOOL( "connectDevice(TQString)", deviceName ); } -bool KMobileClient::disconnectDevice( TQString tqdeviceName ) +bool KMobileClient::disconnectDevice( TQString deviceName ) { - RETURN_BOOL( "disconnectDevice(TQString)", tqdeviceName ); + RETURN_BOOL( "disconnectDevice(TQString)", deviceName ); } -bool KMobileClient::connected( TQString tqdeviceName ) +bool KMobileClient::connected( TQString deviceName ) { - RETURN_BOOL( "connected(TQString)", tqdeviceName ); + RETURN_BOOL( "connected(TQString)", deviceName ); } -TQString KMobileClient::tqdeviceClassName( TQString tqdeviceName ) +TQString KMobileClient::deviceClassName( TQString deviceName ) { - RETURN_TQSTRING( "tqdeviceClassName(TQString)", tqdeviceName ); + RETURN_TQSTRING( "deviceClassName(TQString)", deviceName ); } -TQString KMobileClient::tqdeviceName( TQString tqdeviceName ) +TQString KMobileClient::deviceName( TQString deviceName ) { - RETURN_TQSTRING( "tqdeviceName(TQString)", tqdeviceName ); + RETURN_TQSTRING( "deviceName(TQString)", deviceName ); } -TQString KMobileClient::revision( TQString tqdeviceName ) +TQString KMobileClient::revision( TQString deviceName ) { - RETURN_TQSTRING( "revision(TQString)", tqdeviceName ); + RETURN_TQSTRING( "revision(TQString)", deviceName ); } -int KMobileClient::classType( TQString tqdeviceName ) +int KMobileClient::classType( TQString deviceName ) { - RETURN_INT( "classType(TQString)", tqdeviceName ); + RETURN_INT( "classType(TQString)", deviceName ); } -int KMobileClient::capabilities( TQString tqdeviceName ) +int KMobileClient::capabilities( TQString deviceName ) { - RETURN_INT( "capabilities(TQString)", tqdeviceName ); + RETURN_INT( "capabilities(TQString)", deviceName ); } -TQString KMobileClient::nameForCap( TQString tqdeviceName, int cap ) +TQString KMobileClient::nameForCap( TQString deviceName, int cap ) { - RETURN_TQSTRING( "nameForCap(TQString,int)", tqdeviceName << cap ); + RETURN_TQSTRING( "nameForCap(TQString,int)", deviceName << cap ); } -TQString KMobileClient::iconFileName( TQString tqdeviceName ) +TQString KMobileClient::iconFileName( TQString deviceName ) { - RETURN_TQSTRING( "iconFileName(TQString)", tqdeviceName ); + RETURN_TQSTRING( "iconFileName(TQString)", deviceName ); } -int KMobileClient::numAddresses( TQString tqdeviceName ) +int KMobileClient::numAddresses( TQString deviceName ) { - RETURN_INT( "numAddresses(TQString)", tqdeviceName ); + RETURN_INT( "numAddresses(TQString)", deviceName ); } -TQString KMobileClient::readAddress( TQString tqdeviceName, int index ) +TQString KMobileClient::readAddress( TQString deviceName, int index ) { - RETURN_TQSTRING( "readAddress(TQString,int)", tqdeviceName << index ); + RETURN_TQSTRING( "readAddress(TQString,int)", deviceName << index ); } -bool KMobileClient::storeAddress( TQString tqdeviceName, int index, TQString vcard, bool append ) +bool KMobileClient::storeAddress( TQString deviceName, int index, TQString vcard, bool append ) { - RETURN_BOOL( "storeAddress(TQString,int,TQString,bool)", tqdeviceName << index << vcard << append ); + RETURN_BOOL( "storeAddress(TQString,int,TQString,bool)", deviceName << index << vcard << append ); } -int KMobileClient::numCalendarEntries( TQString tqdeviceName ) +int KMobileClient::numCalendarEntries( TQString deviceName ) { - RETURN_INT( "numCalendarEntries(TQString)", tqdeviceName ); + RETURN_INT( "numCalendarEntries(TQString)", deviceName ); } -int KMobileClient::numNotes( TQString tqdeviceName ) +int KMobileClient::numNotes( TQString deviceName ) { - RETURN_INT( "numNotes(TQString)", tqdeviceName ); + RETURN_INT( "numNotes(TQString)", deviceName ); } -TQString KMobileClient::readNote( TQString tqdeviceName, int index ) +TQString KMobileClient::readNote( TQString deviceName, int index ) { - RETURN_TQSTRING( "readNote(TQString,int)", tqdeviceName << index ); + RETURN_TQSTRING( "readNote(TQString,int)", deviceName << index ); } -bool KMobileClient::storeNote( TQString tqdeviceName, int index, TQString note ) +bool KMobileClient::storeNote( TQString deviceName, int index, TQString note ) { - RETURN_BOOL( "storeNote(TQString,int,TQString)", tqdeviceName << index << note ); + RETURN_BOOL( "storeNote(TQString,int,TQString)", deviceName << index << note ); } diff --git a/kmobile/kmobileclient.h b/kmobile/kmobileclient.h index 6e5f26b7..8456776c 100644 --- a/kmobile/kmobileclient.h +++ b/kmobile/kmobileclient.h @@ -24,34 +24,34 @@ public: /** * DCOP implementation */ - TQStringList tqdeviceNames(); + TQStringList deviceNames(); - void removeDevice( TQString tqdeviceName ); - void configDevice( TQString tqdeviceName ); + void removeDevice( TQString deviceName ); + void configDevice( TQString deviceName ); - bool connectDevice( TQString tqdeviceName ); - bool disconnectDevice( TQString tqdeviceName ); - bool connected( TQString tqdeviceName ); + bool connectDevice( TQString deviceName ); + bool disconnectDevice( TQString deviceName ); + bool connected( TQString deviceName ); - TQString tqdeviceClassName( TQString tqdeviceName ); - TQString tqdeviceName( TQString tqdeviceName ); - TQString revision( TQString tqdeviceName ); - int classType( TQString tqdeviceName ); + TQString deviceClassName( TQString deviceName ); + TQString deviceName( TQString deviceName ); + TQString revision( TQString deviceName ); + int classType( TQString deviceName ); - int capabilities( TQString tqdeviceName ); - TQString nameForCap( TQString tqdeviceName, int cap ); + int capabilities( TQString deviceName ); + TQString nameForCap( TQString deviceName, int cap ); - TQString iconFileName( TQString tqdeviceName ); + TQString iconFileName( TQString deviceName ); - int numAddresses( TQString tqdeviceName ); - TQString readAddress( TQString tqdeviceName, int index ); - bool storeAddress( TQString tqdeviceName, int index, TQString vcard, bool append ); + int numAddresses( TQString deviceName ); + TQString readAddress( TQString deviceName, int index ); + bool storeAddress( TQString deviceName, int index, TQString vcard, bool append ); - int numCalendarEntries( TQString tqdeviceName ); + int numCalendarEntries( TQString deviceName ); - int numNotes( TQString tqdeviceName ); - TQString readNote( TQString tqdeviceName, int index ); - bool storeNote( TQString tqdeviceName, int index, TQString note ); + int numNotes( TQString deviceName ); + TQString readNote( TQString deviceName, int index ); + bool storeNote( TQString deviceName, int index, TQString note ); private: TQCString m_clientAppId; diff --git a/kmobile/kmobiledevice.cpp b/kmobile/kmobiledevice.cpp index a4d807da..36c6bacb 100644 --- a/kmobile/kmobiledevice.cpp +++ b/kmobile/kmobiledevice.cpp @@ -44,7 +44,7 @@ #define PRINT_DEBUG kdDebug(KMOBILEDEVICE_DEBUG_AREA) << "KMobileDevice: " /** - * The base plugin class of all mobile tqdevice drivers. + * The base plugin class of all mobile device drivers. */ KMobileDevice::KMobileDevice(TQObject *obj, const char *name, const TQStringList &args) @@ -53,8 +53,8 @@ KMobileDevice::KMobileDevice(TQObject *obj, const char *name, const TQStringList { setClassType(Unclassified); setCapabilities(hasNothing); - m_tqdeviceName = i18n("Unknown Device"); - m_tqdeviceRevision = i18n("n/a"); /* not available */ + m_deviceName = i18n("Unknown Device"); + m_deviceRevision = i18n("n/a"); /* not available */ m_connectionName = i18n("Unknown Connection"); // set the config file name @@ -63,7 +63,7 @@ KMobileDevice::KMobileDevice(TQObject *obj, const char *name, const TQStringList m_config = new KConfig(); else m_config = new KConfig(m_configFileName); - PRINT_DEBUG << TQString("name of config file is %1\n").tqarg(m_configFileName); + PRINT_DEBUG << TQString("name of config file is %1\n").arg(m_configFileName); } KMobileDevice::~KMobileDevice() @@ -78,20 +78,20 @@ bool KMobileDevice::connected() } // returns e.g. "Nokia mobile phone", "MP3 Player", "Handspring Organizer" -TQString KMobileDevice::tqdeviceClassName() const +TQString KMobileDevice::deviceClassName() const { - return m_tqdeviceClassName; + return m_deviceClassName; } -// returns real tqdevice name, e.g. "Nokia 6310" or "Rio MP3 Player" -TQString KMobileDevice::tqdeviceName() const +// returns real device name, e.g. "Nokia 6310" or "Rio MP3 Player" +TQString KMobileDevice::deviceName() const { - return m_tqdeviceName; + return m_deviceName; } TQString KMobileDevice::revision() const { - return m_tqdeviceRevision; + return m_deviceRevision; } bool KMobileDevice::isSlowDevice() const @@ -107,15 +107,15 @@ bool KMobileDevice::isReadOnly() const bool KMobileDevice::configDialog( TQWidget *parent ) { KMessageBox::information( parent, - i18n("This tqdevice does not need any configuration."), - tqdeviceName() ); + i18n("This device does not need any configuration."), + deviceName() ); return true; } void KMobileDevice::setClassType( enum ClassType ct ) { m_classType = ct; - m_tqdeviceClassName = defaultClassName(ct); + m_deviceClassName = defaultClassName(ct); } enum KMobileDevice::ClassType KMobileDevice::classType() const @@ -239,7 +239,7 @@ int KMobileDevice::storeNote( int, const TQString & ) /* * File storage support - * @param fileName path and name of a file in the mobile tqdevice, e.g. "/MYFILE.TXT", "/mp3/song1.mp3" + * @param fileName path and name of a file in the mobile device, e.g. "/MYFILE.TXT", "/mp3/song1.mp3" */ static @@ -260,7 +260,7 @@ void KMobileDevice::createDirEntry(KIO::UDSEntry& entry, const TQString& name, c addAtom(entry, KIO::UDS_ACCESS, 0500); addAtom(entry, KIO::UDS_MIME_TYPE, 0, mime); addAtom(entry, KIO::UDS_URL, 0, url); - PRINT_DEBUG << TQString("createDirEntry: File: %1 MIME: %2 URL: %3\n").tqarg(name).tqarg(mime).tqarg(url); + PRINT_DEBUG << TQString("createDirEntry: File: %1 MIME: %2 URL: %3\n").arg(name).arg(mime).arg(url); // addAtom(entry, KIO::UDS_SIZE, 0); addAtom(entry, KIO::UDS_GUESSED_MIME_TYPE, 0, mime); } @@ -276,7 +276,7 @@ void KMobileDevice::createFileEntry(KIO::UDSEntry& entry, const TQString& name, addAtom(entry, KIO::UDS_MIME_TYPE, 0, mime); if (size) addAtom(entry, KIO::UDS_SIZE, size); addAtom(entry, KIO::UDS_GUESSED_MIME_TYPE, 0, mime); - PRINT_DEBUG << TQString("createFileEntry: File: %1, Size: %2, MIME: %3\n").tqarg(name).tqarg(size).tqarg(mime); + PRINT_DEBUG << TQString("createFileEntry: File: %1, Size: %2, MIME: %3\n").arg(name).arg(size).arg(mime); } @@ -339,7 +339,7 @@ void KMobileDevice::special( const TQByteArray & ) /* - * tqdevice locking/unlocking functions + * device locking/unlocking functions */ #ifdef HAVE_BAUDBOY_H @@ -374,7 +374,7 @@ void KMobileDevice::special( const TQByteArray & ) #define DEVICE_LOCK_PATH_PREFIX "/var/lock/LCK.." -bool KMobileDevice::lockDevice(const TQString &tqdevice, TQString &err_reason) +bool KMobileDevice::lockDevice(const TQString &device, TQString &err_reason) { #ifdef HAVE_BAUDBOY_H return ttylock(device.local8bit()) == EXIT_SUCCESS; @@ -383,9 +383,9 @@ bool KMobileDevice::lockDevice(const TQString &tqdevice, TQString &err_reason) return !dev_lock(device.local8bit()); # else int pid = -1; - TQStringList all = TQStringList::split('/', tqdevice); + TQStringList all = TQStringList::split('/', device); if (!all.count()) { - err_reason = i18n("Invalid tqdevice (%1)").tqarg(tqdevice); + err_reason = i18n("Invalid device (%1)").arg(device); return false; } TQString lockName = DEVICE_LOCK_PATH_PREFIX + all[all.count()-1]; @@ -393,7 +393,7 @@ bool KMobileDevice::lockDevice(const TQString &tqdevice, TQString &err_reason) if (file.exists() && file.open(IO_ReadOnly)) { if (file.size() == 0) { err_reason = i18n("Unable to read lockfile %s. Please check for reason and " - "remove the lockfile by hand.").tqarg(lockName); + "remove the lockfile by hand.").arg(lockName); PRINT_DEBUG << err_reason; return false; } @@ -406,16 +406,16 @@ bool KMobileDevice::lockDevice(const TQString &tqdevice, TQString &err_reason) file.close(); if (pid > 0 && kill((pid_t)pid, 0) < 0 && errno == ESRCH) { - PRINT_DEBUG << TQString("Lockfile %1 is stale. Overriding it..\n").tqarg(lockName); + PRINT_DEBUG << TQString("Lockfile %1 is stale. Overriding it..\n").arg(lockName); sleep(1); if (!file.remove()) { PRINT_DEBUG << TQString("Overriding failed, please check the permissions\n"); - PRINT_DEBUG << TQString("Cannot lock tqdevice %1\n").tqarg(tqdevice); - err_reason = i18n("Lockfile %1 is stale. Please check permissions.").tqarg(lockName); + PRINT_DEBUG << TQString("Cannot lock device %1\n").arg(device); + err_reason = i18n("Lockfile %1 is stale. Please check permissions.").arg(lockName); return false; } } else { - err_reason = i18n("Device %1 already locked.").tqarg(tqdevice); + err_reason = i18n("Device %1 already locked.").arg(device); return false; } } @@ -424,22 +424,22 @@ bool KMobileDevice::lockDevice(const TQString &tqdevice, TQString &err_reason) int fd = open(lockName.local8Bit(), O_CREAT | O_EXCL | O_WRONLY, 0644); if (fd == -1) { if (errno == EEXIST) - err_reason = i18n("Device %1 seems to be locked by unknown process.").tqarg(tqdevice); + err_reason = i18n("Device %1 seems to be locked by unknown process.").arg(device); else if (errno == EACCES) err_reason = i18n("Please check permission on lock directory."); else if (errno == ENOENT) - err_reason = i18n("Cannot create lockfile %1. Please check for existence of path.").tqarg(lockName); + err_reason = i18n("Cannot create lockfile %1. Please check for existence of path.").arg(lockName); else - err_reason = i18n("Could not create lockfile %1. Error-Code is %2.").tqarg(lockName).tqarg(errno); + err_reason = i18n("Could not create lockfile %1. Error-Code is %2.").arg(lockName).arg(errno); return false; } TQString lockText; - lockText = TQString("%1 kmobile\n").tqarg(getpid(),10); + lockText = TQString("%1 kmobile\n").arg(getpid(),10); write(fd, lockText.utf8(), lockText.utf8().length()); close(fd); PRINT_DEBUG << TQString("%1: Device %2 locked with lockfile %3.\n") - .tqarg(tqdeviceName()).tqarg(tqdevice).tqarg(lockName); + .arg(deviceName()).arg(device).arg(lockName); err_reason = TQString(); @@ -448,7 +448,7 @@ bool KMobileDevice::lockDevice(const TQString &tqdevice, TQString &err_reason) #endif } -bool KMobileDevice::unlockDevice(const TQString &tqdevice) +bool KMobileDevice::unlockDevice(const TQString &device) { #ifdef HAVE_BAUDBOY_H return ttyunlock(device.local8bit()) == EXIT_SUCCESS; @@ -456,7 +456,7 @@ bool KMobileDevice::unlockDevice(const TQString &tqdevice) # ifdef HAVE_LOCKDEV_H return 0 <= dev_unlock(device.local8bit(), getpid()); # else - TQStringList all = TQStringList::split('/', tqdevice); + TQStringList all = TQStringList::split('/', device); if (!all.count()) return false; TQString lockName = DEVICE_LOCK_PATH_PREFIX + all[all.count()-1]; TQFile file(lockName); diff --git a/kmobile/kmobiledevice.h b/kmobile/kmobiledevice.h index 94b73b77..b0b1a654 100644 --- a/kmobile/kmobiledevice.h +++ b/kmobile/kmobiledevice.h @@ -37,20 +37,20 @@ class KConfig; -#define KMOBILE_MIMETYPE_DEVICE "kdetqdevice/mobiletqdevice" -#define KMOBILE_MIMETYPE_DEVICE_KONTQUEROR(name) TQString("kdetqdevice/kmobile_%1").tqarg(name) +#define KMOBILE_MIMETYPE_DEVICE "kdedevice/mobiledevice" +#define KMOBILE_MIMETYPE_DEVICE_KONTQUEROR(name) TQString("kdedevice/kmobile_%1").arg(name) #define KMOBILE_MIMETYPE_INODE "inode/" #define KMOBILE_ICON_UNKNOWN "mobile_unknown" /** - * @short Represents the base class for dynamically loaded mobile tqdevice drivers. + * @short Represents the base class for dynamically loaded mobile device drivers. * - * KMobileDevice is the base class for all hardware tqdevice drivers. + * KMobileDevice is the base class for all hardware device drivers. * Every derived class has to add additional functionality. * * For a KMobileSomeDevice driver you have to write the following code: *

- * K_EXPORT_COMPONENT_FACTORY( libkmobile_sometqdevice, KMobileSomeDevice() );
+ * K_EXPORT_COMPONENT_FACTORY( libkmobile_somedevice, KMobileSomeDevice() );
  * TQObject *KMobileSomeDevice::createObject( TQObject *parent, const char *name,
  *      const char *, const TQStringList &args )
  * {
@@ -95,34 +95,34 @@ public:
     virtual bool disconnectDevice( TQWidget *parent = 0 ) = 0;
 
     /**
-     * Returns true, if the tqdevice is currently connected and the link is online.
+     * Returns true, if the device is currently connected and the link is online.
      */
     virtual bool connected();
 
     /**
-     * Returns the classname, to which the tqdevice belongs. Examples are e.g.
+     * Returns the classname, to which the device belongs. Examples are e.g.
      *  "Nokia mobile phone", "MP3 Player", "Handspring Organizer"
      */
-    virtual TQString tqdeviceClassName() const;
+    virtual TQString deviceClassName() const;
 
     /**
-     * Returns the real tqdevices name, e.g. "Nokia 6310" or "Rio MP3 Player"
+     * Returns the real devices name, e.g. "Nokia 6310" or "Rio MP3 Player"
      */
-    virtual TQString tqdeviceName() const;
+    virtual TQString deviceName() const;
 
     /**
-     * Returns the hardware revision of the tqdevices, e.g. "Revision 1.2"
+     * Returns the hardware revision of the devices, e.g. "Revision 1.2"
      */
     virtual TQString revision() const;
 
     /**
-     * Returns an unique ID for the tqdevice, e.g. IMEI number on phones, or serial number.
+     * Returns an unique ID for the device, e.g. IMEI number on phones, or serial number.
      * The returned String is used to have a unique identification for syncronisation.
      */
-    virtual TQString tqdeviceUniqueID() = 0;
+    virtual TQString deviceUniqueID() = 0;
 
     /**
-     * Returns true, if the tqdevice is connected via a slow connection.
+     * Returns true, if the device is connected via a slow connection.
      * Good examples for slow connections are serial or infrared ports.
      */
     virtual bool isSlowDevice() const;
@@ -133,7 +133,7 @@ public:
     virtual bool isReadOnly() const;
 
     /**
-     * Pop-up a tqdevice-specific configuration dialog.
+     * Pop-up a device-specific configuration dialog.
      *
      * @param parent The parent widget. It will be used as parent for the configuration dialog.
      */
@@ -158,14 +158,14 @@ public:
     static TQString defaultIconFileName( ClassType ct = Unclassified );
     static TQString defaultClassName( ClassType ct = Unclassified );
 
-    // The capabilities of this tqdevice (bitmapped value)
+    // The capabilities of this device (bitmapped value)
     enum Capabilities {
 	hasNothing     = 0,	// not supported
 	hasAddressBook = 1,	// mobile phones, organizers, ...
 	hasCalendar    = 2,	// organizers, mobile phones, ...
 	hasNotes       = 4,	// organizers, mobile phones, ...
 	hasFileStorage = 8,	// organizers, handhelds, mp3-player, ...
-	hasAnyCapability = 0xffff // used to select tqdevices independent of the capatibilities
+	hasAnyCapability = 0xffff // used to select devices independent of the capatibilities
     };
     int capabilities() const;
     const TQString nameForCap(int cap) const;
@@ -206,7 +206,7 @@ public:
      */
 
     /**
-     * helper functions for the kmobile tqdevice drivers
+     * helper functions for the kmobile device drivers
      */
     void createDirEntry(KIO::UDSEntry& entry, const TQString& name,
 		const TQString& url, const TQString& mime) const;
@@ -471,7 +471,7 @@ signals:
     void connectionChanged( bool conn_established );
 
 protected:
-    // only available to sub-classed tqdevice drivers:
+    // only available to sub-classed device drivers:
     void setClassType( enum ClassType ct );
     void setCapabilities( int caps );
     KConfig *config() const { return m_config; };
@@ -479,21 +479,21 @@ protected:
 
 
     /**
-     * Lock/Unlock serial ports and other tqdevices
-     * @param tqdevice Name of a tqdevice port (e.g. /dev/ttyS1, ttyS1, /dev/ircomm0)
-     * Returns true, if tqdevice could be locked or unlocked
+     * Lock/Unlock serial ports and other devices
+     * @param device Name of a device port (e.g. /dev/ttyS1, ttyS1, /dev/ircomm0)
+     * Returns true, if device could be locked or unlocked
      */
-    bool lockDevice(const TQString &tqdevice, TQString &err_reason);
-    bool unlockDevice(const TQString &tqdevice);
+    bool lockDevice(const TQString &device, TQString &err_reason);
+    bool unlockDevice(const TQString &device);
 
 protected:
-    TQMutex  m_mutex;		// mutex to syncronize DCOP accesses to this tqdevice
+    TQMutex  m_mutex;		// mutex to syncronize DCOP accesses to this device
     TQString m_configFileName;
-    KConfig *m_config;		// this is where this tqdevice should store it's configuration
+    KConfig *m_config;		// this is where this device should store it's configuration
     enum ClassType m_classType;
-    TQString m_tqdeviceClassName;	// e.g. "Nokia mobile phone", "MP3 Player", "Handspring Organizer"
-    TQString m_tqdeviceName;	// e.g. "Nokia 6310", "Opie"
-    TQString m_tqdeviceRevision;	// e.g. "Revision 1.2" or "n/a"
+    TQString m_deviceClassName;	// e.g. "Nokia mobile phone", "MP3 Player", "Handspring Organizer"
+    TQString m_deviceName;	// e.g. "Nokia 6310", "Opie"
+    TQString m_deviceRevision;	// e.g. "Revision 1.2" or "n/a"
     TQString m_connectionName;	// e.g. "IRDA", "USB", "Cable", "gnokii", "gammu", ...
     int m_caps;			// see enum Capabilities
     bool m_connected;
diff --git a/kmobile/kmobileitem.cpp b/kmobile/kmobileitem.cpp
index 3778f1c1..d895a366 100644
--- a/kmobile/kmobileitem.cpp
+++ b/kmobile/kmobileitem.cpp
@@ -37,9 +37,9 @@ KMobileItem::KMobileItem(TQIconView *parent, KConfig *_config, KService::Ptr ser
    Q_CHECK_PTR(service);
    if (service) {
 	setText(service->name());
-	m_tqdeviceDesktopFile = service->desktopEntryName();
-	m_tqdeviceConfigFile = TQString("kmobile_%1_rc").tqarg(text());
-	m_tqdeviceConfigFile = m_tqdeviceConfigFile.replace(' ', "");
+	m_deviceDesktopFile = service->desktopEntryName();
+	m_deviceConfigFile = TQString("kmobile_%1_rc").arg(text());
+	m_deviceConfigFile = m_deviceConfigFile.replace(' ', "");
 	m_iconName = service->icon();
    };
 
@@ -75,8 +75,8 @@ void KMobileItem::configSave() const
 {
    config->setGroup( config_SectionName() );
    config->writeEntry( "Name", text() );
-   config->writeEntry( "Config", m_tqdeviceConfigFile );
-   config->writeEntry( "DesktopFile", m_tqdeviceDesktopFile );
+   config->writeEntry( "Config", m_deviceConfigFile );
+   config->writeEntry( "DesktopFile", m_deviceDesktopFile );
    config->writeEntry( "IconName", m_iconName );
    config->sync();
 }
@@ -85,12 +85,12 @@ bool KMobileItem::configLoad(int idx)
 {
    config->setGroup( config_SectionName(idx) );
    setText( config->readEntry("Name") );
-   m_tqdeviceConfigFile	= config->readEntry( "Config" );
-   m_tqdeviceDesktopFile	= config->readEntry( "DesktopFile" );
+   m_deviceConfigFile	= config->readEntry( "Config" );
+   m_deviceDesktopFile	= config->readEntry( "DesktopFile" );
    m_iconName		= config->readEntry( "IconName" );
 
-   if (text().isEmpty() || m_tqdeviceConfigFile.isEmpty() ||
-	m_tqdeviceDesktopFile.isEmpty() || m_iconName.isEmpty() )
+   if (text().isEmpty() || m_deviceConfigFile.isEmpty() ||
+	m_deviceDesktopFile.isEmpty() || m_iconName.isEmpty() )
 	return false;
 
    return true;
@@ -104,7 +104,7 @@ TQPixmap KMobileItem::getIcon() const
 TQString KMobileItem::config_SectionName(int idx) const
 {
    if (idx == -1) idx = index();
-   return TQString("MobileDevice_%1").tqarg(idx);
+   return TQString("MobileDevice_%1").arg(idx);
 }
 
 /* this MimeType is used by konqueror */
@@ -125,7 +125,7 @@ void KMobileItem::writeKonquMimeFile() const
 
    TQString comment;
    if (m_dev)
-	comment = m_dev->tqdeviceClassName();
+	comment = m_dev->deviceClassName();
    if (comment.isEmpty())
 	comment = KMobileDevice::defaultClassName(KMobileDevice::Unclassified);
 
@@ -142,7 +142,7 @@ void KMobileItem::writeKonquMimeFile() const
 
 
 /*
- * get a list of all services providing a libkmobile tqdevice driver
+ * get a list of all services providing a libkmobile device driver
  */
 KTrader::OfferList KMobileItem::getMobileDevicesList()
 {
@@ -158,16 +158,16 @@ KService::Ptr KMobileItem::getServicePtr() const
   KService::Ptr ptr;
   for ( it = list.begin(); it != list.end(); ++it ) {
     KService::Ptr ptr = *it;
-    if (ptr->desktopEntryName() == m_tqdeviceDesktopFile)
+    if (ptr->desktopEntryName() == m_deviceDesktopFile)
  	return ptr;
   }
   PRINT_DEBUG << TQString("Service for library '%1' not found in KService list\n")
-			.tqarg(m_tqdeviceDesktopFile);
+			.arg(m_deviceDesktopFile);
   return 0L;
 }
 
 /*
- * loads & initializes the tqdevice and returns a pointer to it.
+ * loads & initializes the device and returns a pointer to it.
  */
 bool KMobileItem::driverAvailable()
 {
@@ -178,15 +178,15 @@ bool KMobileItem::driverAvailable()
    if (!ptr)
 	return false;
 
-   PRINT_DEBUG << TQString("Loading library %1\n").tqarg(ptr->library());
+   PRINT_DEBUG << TQString("Loading library %1\n").arg(ptr->library());
    KLibFactory *factory = KLibLoader::self()->factory( ptr->library().utf8() );
    if (!factory)
 	return false;
 
    m_dev = static_cast(factory->create(this, ptr->name().utf8(),
-				"KMobileDevice", TQStringList(m_tqdeviceConfigFile)));
+				"KMobileDevice", TQStringList(m_deviceConfigFile)));
    PRINT_DEBUG << TQString("Got KMobileDevice object at 0x%1, configfile=%2\n")
-			.tqarg((unsigned long)m_dev, 0, 16).tqarg(m_tqdeviceConfigFile);
+			.arg((unsigned long)m_dev, 0, 16).arg(m_deviceConfigFile);
 
    return (m_dev != 0);
 }
diff --git a/kmobile/kmobileitem.h b/kmobile/kmobileitem.h
index e82a5cb1..ba204265 100644
--- a/kmobile/kmobileitem.h
+++ b/kmobile/kmobileitem.h
@@ -44,8 +44,8 @@ private slots:
 private:
     KConfig *config;
 
-    TQString m_tqdeviceConfigFile;
-    TQString m_tqdeviceDesktopFile;
+    TQString m_deviceConfigFile;
+    TQString m_deviceDesktopFile;
 
     TQString m_iconName;
 };
diff --git a/kmobile/kmobileui.rc b/kmobile/kmobileui.rc
index 9b259334..95af1dd3 100644
--- a/kmobile/kmobileui.rc
+++ b/kmobile/kmobileui.rc
@@ -8,22 +8,22 @@
   
   
     &Device
-    
-    
+    
+    
     
-    
-    
+    
+    
     
-    
+    
   
  
  
   Main Toolbar
   
   
-  
-  
+  
+  
   
-  
+  
  
 
diff --git a/kmobile/libkmobile.desktop b/kmobile/libkmobile.desktop
index f5a1e746..b6444d2a 100644
--- a/kmobile/libkmobile.desktop
+++ b/kmobile/libkmobile.desktop
@@ -1,6 +1,6 @@
 [Desktop Entry]
 Type=ServiceType
-X-KDE-ServiceType=kdetqdevice/mobiletqdevice
+X-KDE-ServiceType=kdedevice/mobiledevice
 Name=KDE Mobile Device Lowlevel Hardware Driver
 Name[af]=KDE draagbare toestel laevlak hardeware toestel
 Name[bs]=KDE hardverski drajver niskog nivoa za mobilne uređaje
diff --git a/kmobile/main.cpp b/kmobile/main.cpp
index c9d7d124..1b03f971 100644
--- a/kmobile/main.cpp
+++ b/kmobile/main.cpp
@@ -25,7 +25,7 @@
 #include 
 
 static const char description[] =
-    I18N_NOOP("KDE mobile tqdevices manager");
+    I18N_NOOP("KDE mobile devices manager");
 
 static const char version[] = "0.1";
 
diff --git a/kmobile/testlibkmobile.cpp b/kmobile/testlibkmobile.cpp
index 774a191e..e8ff8558 100644
--- a/kmobile/testlibkmobile.cpp
+++ b/kmobile/testlibkmobile.cpp
@@ -25,16 +25,16 @@ int main(int argc, char **argv)
 
     TQCString replyType;
     TQByteArray replyData;
-    ok = client->call("kmobile", "kmobileIface", "tqdeviceNames()", data, replyType, replyData);
+    ok = client->call("kmobile", "kmobileIface", "deviceNames()", data, replyType, replyData);
 
     TQDataStream reply(replyData, IO_ReadOnly); 
-    TQStringList tqdeviceNames; 
-    reply >> tqdeviceNames;
+    TQStringList deviceNames; 
+    reply >> deviceNames;
 
-    kdDebug() << TQString("%1\n").tqarg(ok?"Ok":"Failure");
-    kdDebug() << TQString("Number of currently registered drivers: %1\n").tqarg(tqdeviceNames.count());
-    for (int i=0; i
diff --git a/kmobile/kmobileiface.h b/kmobile/kmobileiface.h
index 5d39f236..60974b26 100644
--- a/kmobile/kmobileiface.h
+++ b/kmobile/kmobileiface.h
@@ -16,40 +16,40 @@ class kmobileIface : virtual public DCOPObject
 public:
 
 k_dcop:
-    virtual TQStringList tqdeviceNames() = 0;
+    virtual TQStringList deviceNames() = 0;
 
-    virtual void removeDevice( TQString tqdeviceName ) = 0;
-    virtual void configDevice( TQString tqdeviceName ) = 0;
+    virtual void removeDevice( TQString deviceName ) = 0;
+    virtual void configDevice( TQString deviceName ) = 0;
 
-    virtual bool connectDevice( TQString tqdeviceName ) = 0;
-    virtual bool disconnectDevice( TQString tqdeviceName ) = 0;
-    virtual bool connected( TQString tqdeviceName ) = 0;
+    virtual bool connectDevice( TQString deviceName ) = 0;
+    virtual bool disconnectDevice( TQString deviceName ) = 0;
+    virtual bool connected( TQString deviceName ) = 0;
 
-    virtual TQString tqdeviceClassName( TQString tqdeviceName ) = 0;
-    virtual TQString tqdeviceName( TQString tqdeviceName ) = 0;
-    virtual TQString revision( TQString tqdeviceName ) = 0;
-    virtual int classType( TQString tqdeviceName ) = 0;
+    virtual TQString deviceClassName( TQString deviceName ) = 0;
+    virtual TQString deviceName( TQString deviceName ) = 0;
+    virtual TQString revision( TQString deviceName ) = 0;
+    virtual int classType( TQString deviceName ) = 0;
 
-    virtual int capabilities( TQString tqdeviceName ) = 0;
-    virtual TQString nameForCap( TQString tqdeviceName, int cap ) = 0;
+    virtual int capabilities( TQString deviceName ) = 0;
+    virtual TQString nameForCap( TQString deviceName, int cap ) = 0;
 
-    virtual TQString iconFileName( TQString tqdeviceName ) = 0;
+    virtual TQString iconFileName( TQString deviceName ) = 0;
 
-    virtual int     numAddresses( TQString tqdeviceName ) = 0;
-    virtual TQString readAddress( TQString tqdeviceName, int index ) = 0;
-    virtual bool    storeAddress( TQString tqdeviceName, int index, TQString vcard, bool append ) = 0;
+    virtual int     numAddresses( TQString deviceName ) = 0;
+    virtual TQString readAddress( TQString deviceName, int index ) = 0;
+    virtual bool    storeAddress( TQString deviceName, int index, TQString vcard, bool append ) = 0;
 
-    virtual int numCalendarEntries( TQString tqdeviceName ) = 0;
+    virtual int numCalendarEntries( TQString deviceName ) = 0;
 
-    virtual int numNotes( TQString tqdeviceName ) = 0;
-    virtual TQString readNote( TQString tqdeviceName, int index ) = 0;
-    virtual bool storeNote( TQString tqdeviceName, int index, TQString note ) = 0;
+    virtual int numNotes( TQString deviceName ) = 0;
+    virtual TQString readNote( TQString deviceName, int index ) = 0;
+    virtual bool storeNote( TQString deviceName, int index, TQString note ) = 0;
 
     /*
      * DCOP functions for the tqdevices:/ kioslave
      */
 k_dcop:
-    virtual TQStringList kio_tqdevices_tqdeviceInfo(TQString tqdeviceName) = 0;
+    virtual TQStringList kio_devices_deviceInfo(TQString deviceName) = 0;
 };
 
 #endif // _KMOBILEIFACE_H_
@@ -16,40 +16,40 @@ class kmobileIface : virtual public DCOPObject
 
     /*
-     * DCOP functions for the tqdevices:/ kioslave
+     * DCOP functions for the devices:/ kioslave
      */
 k_dcop:
diff --git a/kmobile/kmobileview.cpp b/kmobile/kmobileview.cpp
index 26ac4d0b..3770dc0d 100644
--- a/kmobile/kmobileview.cpp
+++ b/kmobile/kmobileview.cpp
@@ -49,10 +49,10 @@ KMobileView::~KMobileView()
 
 bool KMobileView::addNewDevice(KConfig *config, KService::Ptr service)
 {
-   kdDebug() << "New mobile tqdevice item:\n";
+   kdDebug() << "New mobile device item:\n";
    kdDebug() << TQString("LIBRARY: '%1', NAME: '%2', ICON: '%3', COMMENT: '%4'\n")
-		.tqarg(service->library()).tqarg(service->name()).tqarg(service->icon())
-		.tqarg(service->comment());
+		.arg(service->library()).arg(service->name()).arg(service->icon())
+		.arg(service->comment());
 
    KMobileItem *it;
    it = new KMobileItem(this, config, service);
@@ -89,10 +89,10 @@ void KMobileView::restoreAll()
    emit signalChangeStatusbar( i18n("Configuration restored") );
 }
 
-KMobileItem *KMobileView::findDevice( const TQString &tqdeviceName ) const
+KMobileItem *KMobileView::findDevice( const TQString &deviceName ) const
 {
    for ( TQIconViewItem *item = firstItem(); item; item = item->nextItem() ) {
-	if (item->text() == tqdeviceName)
+	if (item->text() == deviceName)
 		return static_cast(item);
    }
    return 0L;
@@ -119,7 +119,7 @@ void KMobileView::slotDoubleClicked( TQIconViewItem * item )
 #define MUTEX_UNLOCK(dev)  dev->m_mutex.unlock(); }
 
 
-TQStringList KMobileView::tqdeviceNames()
+TQStringList KMobileView::deviceNames()
 {
    TQStringList names;
    for ( TQIconViewItem *item = firstItem(); item; item = item->nextItem() ) {
@@ -128,15 +128,15 @@ TQStringList KMobileView::tqdeviceNames()
    return names;
 }
 
-void KMobileView::removeDevice( TQString tqdeviceName )
+void KMobileView::removeDevice( TQString deviceName )
 {
-   delete findDevice(tqdeviceName);
-   emit signalChangeStatusbar( i18n("%1 removed").tqarg(tqdeviceName) );
+   delete findDevice(deviceName);
+   emit signalChangeStatusbar( i18n("%1 removed").arg(deviceName) );
 }
 
-void KMobileView::configDevice( TQString tqdeviceName )
+void KMobileView::configDevice( TQString deviceName )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return;
    MUTEX_LOCK(dev->m_dev);
@@ -145,9 +145,9 @@ void KMobileView::configDevice( TQString tqdeviceName )
 }
 
 
-bool KMobileView::connectDevice( TQString tqdeviceName )
+bool KMobileView::connectDevice( TQString deviceName )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return false;
    bool connected;
@@ -155,14 +155,14 @@ bool KMobileView::connectDevice( TQString tqdeviceName )
    connected = dev->m_dev->connectDevice();
    MUTEX_UNLOCK(dev->m_dev);
    emit signalChangeStatusbar(
-	connected ? i18n("Connection to %1 established").tqarg(tqdeviceName)
-	          : i18n("Connection to %1 failed").tqarg(tqdeviceName) );
+	connected ? i18n("Connection to %1 established").arg(deviceName)
+	          : i18n("Connection to %1 failed").arg(deviceName) );
    return connected;
 }
 
-bool KMobileView::disconnectDevice( TQString tqdeviceName )
+bool KMobileView::disconnectDevice( TQString deviceName )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return true;
    bool disconnected;
@@ -170,14 +170,14 @@ bool KMobileView::disconnectDevice( TQString tqdeviceName )
    disconnected = dev->m_dev->disconnectDevice();
    MUTEX_UNLOCK(dev->m_dev);
    emit signalChangeStatusbar(
-	disconnected ? i18n("%1 disconnected").tqarg(tqdeviceName)
-	             : i18n("Disconnection of %1 failed").tqarg(tqdeviceName) );
+	disconnected ? i18n("%1 disconnected").arg(deviceName)
+	             : i18n("Disconnection of %1 failed").arg(deviceName) );
    return disconnected;
 }
 
-bool KMobileView::connected( TQString tqdeviceName )
+bool KMobileView::connected( TQString deviceName )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return false;
    bool conn;
@@ -188,33 +188,33 @@ bool KMobileView::connected( TQString tqdeviceName )
 }
 
 
-TQString KMobileView::tqdeviceClassName( TQString tqdeviceName )
+TQString KMobileView::deviceClassName( TQString deviceName )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return TQString();
    TQString cn;
    MUTEX_LOCK(dev->m_dev);
-   cn = dev->m_dev->tqdeviceClassName();
+   cn = dev->m_dev->deviceClassName();
    MUTEX_UNLOCK(dev->m_dev);
    return cn;
 }
 
-TQString KMobileView::tqdeviceName( TQString tqdeviceName )
+TQString KMobileView::deviceName( TQString deviceName )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return TQString();
    TQString dn;
    MUTEX_LOCK(dev->m_dev);
-   dn = dev->m_dev->tqdeviceName();
+   dn = dev->m_dev->deviceName();
    MUTEX_UNLOCK(dev->m_dev);
    return dn;
 }
 
-TQString KMobileView::revision( TQString tqdeviceName )
+TQString KMobileView::revision( TQString deviceName )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return TQString();
    TQString rev;
@@ -224,9 +224,9 @@ TQString KMobileView::revision( TQString tqdeviceName )
    return rev;
 }
 
-int KMobileView::classType( TQString tqdeviceName )
+int KMobileView::classType( TQString deviceName )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return KMobileDevice::Unclassified;
    int ct;
@@ -236,9 +236,9 @@ int KMobileView::classType( TQString tqdeviceName )
    return ct;
 }
 
-int KMobileView::capabilities( TQString tqdeviceName )
+int KMobileView::capabilities( TQString deviceName )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return KMobileDevice::hasNothing;
    int cap;
@@ -248,9 +248,9 @@ int KMobileView::capabilities( TQString tqdeviceName )
    return cap;
 }
 
-TQString KMobileView::nameForCap( TQString tqdeviceName, int cap )
+TQString KMobileView::nameForCap( TQString deviceName, int cap )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return TQString();
    TQString nc;
@@ -260,9 +260,9 @@ TQString KMobileView::nameForCap( TQString tqdeviceName, int cap )
    return nc;
 }
 
-TQString KMobileView::iconFileName( TQString tqdeviceName )
+TQString KMobileView::iconFileName( TQString deviceName )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return TQString();
    TQString fn;
@@ -272,9 +272,9 @@ TQString KMobileView::iconFileName( TQString tqdeviceName )
    return fn;
 }
 
-int KMobileView::numAddresses( TQString tqdeviceName )
+int KMobileView::numAddresses( TQString deviceName )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return 0;
    int num;
@@ -284,9 +284,9 @@ int KMobileView::numAddresses( TQString tqdeviceName )
    return num;
 }
 
-TQString KMobileView::readAddress( TQString tqdeviceName, int index )
+TQString KMobileView::readAddress( TQString deviceName, int index )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return TQString();
 
@@ -304,14 +304,14 @@ TQString KMobileView::readAddress( TQString tqdeviceName, int index )
         return TQString();
 
    emit signalChangeStatusbar( i18n("Read addressbook entry %1 from %2")
-		.tqarg(index).tqarg(tqdeviceName) );
+		.arg(index).arg(deviceName) );
 
    return str;
 }
 
-bool KMobileView::storeAddress( TQString tqdeviceName, int index, TQString vcard, bool append )
+bool KMobileView::storeAddress( TQString deviceName, int index, TQString vcard, bool append )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return false;
 
@@ -325,14 +325,14 @@ bool KMobileView::storeAddress( TQString tqdeviceName, int index, TQString vcard
    err = dev->m_dev->storeAddress(index, adr, append);
    MUTEX_UNLOCK(dev->m_dev);
    emit signalChangeStatusbar(
-	err ? i18n("Storing contact %1 on %2 failed").tqarg(index).tqarg(tqdeviceName)
-	    : i18n("Contact %1 stored on %2").tqarg(index).tqarg(tqdeviceName) );
+	err ? i18n("Storing contact %1 on %2 failed").arg(index).arg(deviceName)
+	    : i18n("Contact %1 stored on %2").arg(index).arg(deviceName) );
    return (err == 0);
 }
 
-int KMobileView::numCalendarEntries( TQString tqdeviceName )
+int KMobileView::numCalendarEntries( TQString deviceName )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return 0;
    int num;
@@ -342,9 +342,9 @@ int KMobileView::numCalendarEntries( TQString tqdeviceName )
    return num;
 }
 
-int KMobileView::numNotes( TQString tqdeviceName )
+int KMobileView::numNotes( TQString deviceName )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return 0;
    int num;
@@ -354,9 +354,9 @@ int KMobileView::numNotes( TQString tqdeviceName )
    return num;
 }
 
-TQString KMobileView::readNote( TQString tqdeviceName, int index )
+TQString KMobileView::readNote( TQString deviceName, int index )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return TQString();
 
@@ -368,13 +368,13 @@ TQString KMobileView::readNote( TQString tqdeviceName, int index )
    if (err)
 	return TQString();
    emit signalChangeStatusbar( i18n("Read note %1 from %2")
-		.tqarg(index).tqarg(tqdeviceName) );
+		.arg(index).arg(deviceName) );
    return note;
 }
 
-bool KMobileView::storeNote( TQString tqdeviceName, int index, TQString note )
+bool KMobileView::storeNote( TQString deviceName, int index, TQString note )
 {
-   KMobileItem *dev = findDevice(tqdeviceName);
+   KMobileItem *dev = findDevice(deviceName);
    if (!dev || !dev->driverAvailable())
 	return false;
 
@@ -385,28 +385,28 @@ bool KMobileView::storeNote( TQString tqdeviceName, int index, TQString note )
    if (err)
 	return false;
    emit signalChangeStatusbar( i18n("Stored note %1 to %2")
-		.tqarg(index).tqarg(tqdeviceName) );
+		.arg(index).arg(deviceName) );
    return true;
 }
 
 
 
 /*
  * DCOP Implementation for the tqdevices:/ kioslave
  */
 
 /*
  * returns the information for the given tqdeviceName for usage in the
  * the tqdevices kioslave. The TQStringList returned is comparable to the
  * format of /etc/fstab file. Please refer to the tqdevices kioslave for
  * further information.
  * If tqdeviceName is empty, this functions returns information for all
  * active mobile tqdevices.
  * (function is only used by the tqdevices kioslave - don't use elsewhere !)
  */
-TQStringList KMobileView::kio_tqdevices_tqdeviceInfo(TQString tqdeviceName)
+TQStringList KMobileView::kio_devices_deviceInfo(TQString deviceName)
 {
-   TQStringList mobiles = tqdeviceNames();
+   TQStringList mobiles = deviceNames();
    if (mobiles.count() == 0)
 	return mobiles;
 
@@ -414,10 +414,10 @@ TQStringList KMobileView::kio_tqdevices_tqdeviceInfo(TQString tqdeviceName)
    for ( TQStringList::Iterator it = mobiles.begin(); it != mobiles.end(); ++it ) {
 	TQString name = *it;
 
-	if (tqdeviceName.isEmpty())
+	if (deviceName.isEmpty())
 		mountList << name;
 	else
-		if (tqdeviceName!=name)
+		if (deviceName!=name)
 			continue;
 
 	KMobileItem *dev = findDevice(name);
@@ -425,11 +425,11 @@ TQStringList KMobileView::kio_tqdevices_tqdeviceInfo(TQString tqdeviceName)
 
 	mountList << name;
 	mountList << " ";
-	mountList << TQString("mobile:/%1").tqarg(name); // KIO::encodeFileName()
+	mountList << TQString("mobile:/%1").arg(name); // KIO::encodeFileName()
 	mountList << mime;
 	mountList << "true"; // mountState
 	mountList << "---";
-	if (!tqdeviceName.isEmpty())
+	if (!deviceName.isEmpty())
 		break;
    }
    return mountList;
@@ -385,28 +385,28 @@ bool KMobileView::storeNote( TQString tqdeviceName, int index, TQString note )
 
 /*
- * DCOP Implementation for the tqdevices:/ kioslave
+ * DCOP Implementation for the devices:/ kioslave
  */
 
@@ -385,28 +385,28 @@ bool KMobileView::storeNote( TQString tqdeviceName, int index, TQString note )
 
 /*
- * returns the information for the given tqdeviceName for usage in the
- * the tqdevices kioslave. The TQStringList returned is comparable to the
- * format of /etc/fstab file. Please refer to the tqdevices kioslave for
+ * returns the information for the given deviceName for usage in the
+ * the devices kioslave. The TQStringList returned is comparable to the
+ * format of /etc/fstab file. Please refer to the devices kioslave for
  * further information.
@@ -385,28 +385,28 @@ bool KMobileView::storeNote( TQString tqdeviceName, int index, TQString note )
  * further information.
- * If tqdeviceName is empty, this functions returns information for all
- * active mobile tqdevices.
- * (function is only used by the tqdevices kioslave - don't use elsewhere !)
+ * If deviceName is empty, this functions returns information for all
+ * active mobile devices.
+ * (function is only used by the devices kioslave - don't use elsewhere !)
  */
diff --git a/kmobile/kmobileview.h b/kmobile/kmobileview.h
index 16d2b2e2..ee8b1e53 100644
--- a/kmobile/kmobileview.h
+++ b/kmobile/kmobileview.h
@@ -34,44 +34,44 @@ public:
     /**
      * DCOP implementation
      */
-    TQStringList tqdeviceNames();
+    TQStringList deviceNames();
 
-    void removeDevice( TQString tqdeviceName );
-    void configDevice( TQString tqdeviceName );
+    void removeDevice( TQString deviceName );
+    void configDevice( TQString deviceName );
 
-    bool connectDevice( TQString tqdeviceName );
-    bool disconnectDevice( TQString tqdeviceName );
-    bool connected( TQString tqdeviceName );
+    bool connectDevice( TQString deviceName );
+    bool disconnectDevice( TQString deviceName );
+    bool connected( TQString deviceName );
 
-    TQString tqdeviceClassName( TQString tqdeviceName );
-    TQString tqdeviceName( TQString tqdeviceName );
-    TQString revision( TQString tqdeviceName );
-    int classType( TQString tqdeviceName );
+    TQString deviceClassName( TQString deviceName );
+    TQString deviceName( TQString deviceName );
+    TQString revision( TQString deviceName );
+    int classType( TQString deviceName );
 
-    int capabilities( TQString tqdeviceName );
-    TQString nameForCap( TQString tqdeviceName, int cap );
+    int capabilities( TQString deviceName );
+    TQString nameForCap( TQString deviceName, int cap );
 
-    TQString iconFileName( TQString tqdeviceName );
+    TQString iconFileName( TQString deviceName );
 
-    int     numAddresses( TQString tqdeviceName );
-    TQString readAddress( TQString tqdeviceName, int index );
-    bool    storeAddress( TQString tqdeviceName, int index, TQString vcard, bool append );
+    int     numAddresses( TQString deviceName );
+    TQString readAddress( TQString deviceName, int index );
+    bool    storeAddress( TQString deviceName, int index, TQString vcard, bool append );
 
-    int numCalendarEntries( TQString tqdeviceName );
+    int numCalendarEntries( TQString deviceName );
 
-    int numNotes( TQString tqdeviceName );
-    TQString readNote( TQString tqdeviceName, int index );
-    bool storeNote( TQString tqdeviceName, int index, TQString note );
+    int numNotes( TQString deviceName );
+    TQString readNote( TQString deviceName, int index );
+    bool storeNote( TQString deviceName, int index, TQString note );
 
-    /* tqdevices kioslave support: */
-    TQStringList kio_tqdevices_tqdeviceInfo(TQString tqdeviceName);
+    /* devices kioslave support: */
+    TQStringList kio_devices_deviceInfo(TQString deviceName);
 
 public:
     void saveAll();
     void restoreAll();
 
 protected:
-    KMobileItem * findDevice( const TQString &tqdeviceName ) const;
+    KMobileItem * findDevice( const TQString &deviceName ) const;
 
 protected slots:
     void slotDoubleClicked( TQIconViewItem * item );
diff --git a/kmobile/systemtray.cpp b/kmobile/systemtray.cpp
index c0c0bec0..7796a55b 100644
--- a/kmobile/systemtray.cpp
+++ b/kmobile/systemtray.cpp
@@ -44,7 +44,7 @@ SystemTray::SystemTray(KMainWindow *parent, const char *name) : KSystemTray(pare
     setToolTip();
 
     m_actionCollection = parent->actionCollection();
-    KAction *addAction = m_actionCollection->action("tqdevice_add");
+    KAction *addAction = m_actionCollection->action("device_add");
     
     KPopupMenu* menu = contextMenu();
     addAction->plug(menu);
@@ -67,8 +67,8 @@ void SystemTray::contextMenuAboutToShow(KPopupMenu *menu)
 	   menu->idAt(pos)<=(SYSTEMTRAY_STARTID+1000))
 	menu->removeItemAt(pos);
 
-    // create menu entries for each mobile tqdevice and add it's icon
-    TQStringList list = main->mainView()->tqdeviceNames();
+    // create menu entries for each mobile device and add it's icon
+    TQStringList list = main->mainView()->deviceNames();
     for (unsigned int no=0; nomainView()->iconFileName(devName);